@@ -539,7 +539,7 @@ my $select_an_instance_type=sub {
       }
    }
 #print "DUMP=",Data::Dump::Streamer::Dump(\@sizes)->Out(),"\n";<STDIN>;
-   my $demo_choice=']P[{choose_demo_setup}';
+   my $demo_choice=']T[{choose_demo_setup}';
    $demo_choice=~s/^["]//;
    $demo_choice=~s/["]$//;
    my $ns=$#sizes+1;
@@ -599,7 +599,7 @@ END
 
 my $choose_an_instance_type=sub {
 
-   my $demo_choice=']P[{choose_demo_setup}';
+   my $demo_choice=']T[{choose_demo_setup}';
    $demo_choice=~s/^["]//;
    $demo_choice=~s/["]$//;
    my $instance_type_banner=<<'END';
